@@ -466,7 +466,7 @@ void FullScreenContent::setFullScreenMode(bool fullScreenMode)
 
 void FullScreenContent::setDistractionFreeMode(bool distractionFreeMode)
 {
-    mAutoHideContainer->setAutoHidingEnabled(!distractionFreeMode);
+    mAutoHideContainer->setEdgeTriggerEnabled(!distractionFreeMode);
 }
 
 void FullScreenContent::slotImageMetaInfoDialogClosed()
