@@ -64,11 +64,13 @@ struct GvCorePrivate
     HistoryModel* mRecentFoldersModel;
     RecentFilesModel* mRecentFilesModel;
     QPalette mPalettes[4];
+    QString mFullScreenPaletteName;
 
     bool showSaveAsDialog(const QUrl &url, QUrl* outUrl, QByteArray* format)
     {
         QFileDialog dialog(mMainWindow);
         dialog.setAcceptMode(QFileDialog::AcceptSave);
+        dialog.setWindowTitle(i18nc("@title:window", "Save Image"));
         dialog.selectUrl(url);
 
         QStringList supportedMimetypes;
@@ -127,14 +129,16 @@ struct GvCorePrivate
         QString name = GwenviewConfig::fullScreenColorScheme();
         if (name.isEmpty()) {
             // Default color scheme
-            QString path = QStandardPaths::locate(QStandardPaths::AppDataLocation, "color-schemes/fullscreen.colors");
-            config = KSharedConfig::openConfig(path);
+            mFullScreenPaletteName = QStandardPaths::locate(QStandardPaths::AppDataLocation, "color-schemes/fullscreen.colors");
+            config = KSharedConfig::openConfig(mFullScreenPaletteName);
         } else if (name.contains('/')) {
             // Full path to a .colors file
-            config = KSharedConfig::openConfig(name);
+            mFullScreenPaletteName = name;
+            config = KSharedConfig::openConfig(mFullScreenPaletteName);
         } else {
             // Standard KDE color scheme
-            config = KSharedConfig::openConfig(QString("color-schemes/%1.colors").arg(name), KConfig::FullConfig, QStandardPaths::AppDataLocation);
+            mFullScreenPaletteName = QString("color-schemes/%1.colors").arg(name);
+            config = KSharedConfig::openConfig(mFullScreenPaletteName, KConfig::FullConfig, QStandardPaths::AppDataLocation);
         }
         mPalettes[GvCore::FullScreenPalette] = KColorScheme::createApplicationPalette(config);
 
@@ -170,7 +174,7 @@ GvCore::~GvCore()
 QAbstractItemModel* GvCore::recentFoldersModel() const
 {
     if (!d->mRecentFoldersModel) {
-        d->mRecentFoldersModel = new HistoryModel(const_cast<GvCore*>(this), QStandardPaths::locate(QStandardPaths::AppLocalDataLocation, "recentfolders/"));
+        d->mRecentFoldersModel = new HistoryModel(const_cast<GvCore*>(this), QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation) + "/recentfolders/");
     }
     return d->mRecentFoldersModel;
 }
@@ -374,4 +378,9 @@ QPalette GvCore::palette(GvCore::PaletteType type) const
     return d->mPalettes[type];
 }
 
+QString GvCore::fullScreenPaletteName() const
+{
+    return d->mFullScreenPaletteName;
+}
+
 } // namespace
