@@ -33,6 +33,7 @@ class QUrl;
 
 class QAbstractItemModel;
 class QPalette;
+class QString;
 
 namespace Gwenview
 {
@@ -57,14 +58,15 @@ public:
     };
 
     QAbstractItemModel* recentFoldersModel() const;
-    QAbstractItemModel* recentUrlsModel() const;
+    QAbstractItemModel* recentFilesModel() const;
     SortedDirModel* sortedDirModel() const;
     AbstractSemanticInfoBackEnd* semanticInfoBackEnd() const;
 
     void addUrlToRecentFolders(QUrl);
-    void addUrlToRecentUrls(const QUrl &url);
+    void addUrlToRecentFiles(const QUrl &);
 
     QPalette palette(PaletteType type) const;
+    QString fullScreenPaletteName() const;
 
 public Q_SLOTS:
     void saveAll();
