@@ -26,7 +26,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <QVBoxLayout>
 
 // KDE
-#include <KLocale>
+#include <KLocalizedString>
 
 // Local
 
