@@ -40,6 +40,15 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <lib/imageformats/imageformats.h>
 #include "mainwindow.h"
 
+#ifdef HAVE_FITS
+// This hack is needed to include the fitsplugin moc file in main.cpp
+// Otherwise the linker complains about: undefined reference to `qt_static_plugin_FitsPlugin()'
+// This symbol is defined in the moc file, but it is not a visible symbol after libgwenview is linked.
+// If Q_IMPORT_PLUGIN(FitsPlugin) is moved to the library, gwenview crashes on the first call to FitsPlugin()
+// when the vtable is looked up in the plugin registration.
+#include <../lib/imageformats/moc_fitsplugin.cpp>
+#endif
+
 class StartHelper
 {
 public:
@@ -157,3 +166,7 @@ int main(int argc, char *argv[])
 
     return app.exec();
 }
+
+#ifdef HAVE_FITS
+    Q_IMPORT_PLUGIN(FitsPlugin)
+#endif
