@@ -30,9 +30,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <QSharedData>
 #include <QSize>
 
-// KDE
-#include <KSharedPtr>
-
 // Local
 #include <lib/mimetypeutils.h>
 #include <lib/cms/cmsprofile.h>
@@ -65,7 +62,7 @@ class ImageMetaInfoModel;
  * It is capable of loading down sampled versions of an image using
  * prepareDownSampledImageForZoom() and downSampledImageForZoom(). Down sampled
  * images load much faster than the full image but you need to load the full
- * image to manipulate it( use startLoadingFullImage() to do so).
+ * image to manipulate it (use startLoadingFullImage() to do so).
  *
  * To get a Document instance for url, ask for one with
  * DocumentFactory::instance()->load(url);
@@ -90,7 +87,7 @@ public:
         LoadingFailed   ///< Image loading has failed
     };
 
-    typedef KSharedPtr<Document> Ptr;
+    typedef QExplicitlySharedDataPointer<Document> Ptr;
     ~Document();
 
     /**
