@@ -92,6 +92,15 @@ public:
         return false;
     }
 
+    // Implementation must emit zoomToFitWidthChanged()
+    virtual void setZoomToFitWidth(bool)
+    {}
+
+    virtual bool zoomToFitWidth() const
+    {
+        return false;
+    }
+
     virtual qreal zoom() const
     {
         return 0;
@@ -104,6 +113,11 @@ public:
     {
         return 1.;
     }
+
+    virtual qreal computeZoomToFitWidth() const
+    {
+        return 1.;
+    }
     /** @} */
 
     virtual Document::Ptr document() const = 0;
@@ -140,6 +154,8 @@ Q_SIGNALS:
 
     void zoomToFitChanged(bool);
 
+    void zoomToFitWidthChanged(bool);
+
     void zoomInRequested(const QPointF&);
 
     void zoomOutRequested(const QPointF&);
