@@ -27,21 +27,18 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <QGraphicsWidget>
 
 // KDE
-#include <KActionCollection>
 
 // Local
 #include <lib/document/document.h>
 
 class QPropertyAnimation;
-class KUrl;
+class QUrl;
 
 namespace Gwenview
 {
 
 class AbstractRasterImageViewTool;
 class RasterImageView;
-class SlideShow;
-class ZoomWidget;
 
 struct DocumentViewPrivate;
 
@@ -54,6 +51,7 @@ class GWENVIEWLIB_EXPORT DocumentView : public QGraphicsWidget
     Q_OBJECT
     Q_PROPERTY(qreal zoom READ zoom WRITE setZoom NOTIFY zoomChanged)
     Q_PROPERTY(bool zoomToFit READ zoomToFit WRITE setZoomToFit NOTIFY zoomToFitChanged)
+    Q_PROPERTY(bool zoomToFitWidth READ zoomToFitWidth WRITE setZoomToFitWidth NOTIFY zoomToFitWidthChanged)
     Q_PROPERTY(QPoint position READ position WRITE setPosition NOTIFY positionChanged)
 public:
     static const int MaximumZoom;
@@ -62,11 +60,13 @@ public:
     struct Setup {
         Setup()
         : valid(false)
-        , zoomToFit(false)
+        , zoomToFit(true)
+        , zoomToFitWidth(false)
         , zoom(0)
         {}
         bool valid:1;
         bool zoomToFit:1;
+        bool zoomToFitWidth:1;
         qreal zoom;
         QPointF position;
     };
@@ -86,9 +86,9 @@ public:
 
     Document::Ptr document() const;
 
-    KUrl url() const;
+    QUrl url() const;
 
-    void openUrl(const KUrl&, const Setup&);
+    void openUrl(const QUrl&, const Setup&);
 
     Setup setup() const;
 
@@ -112,6 +112,8 @@ public:
 
     bool zoomToFit() const;
 
+    bool zoomToFitWidth() const;
+
     QPoint position() const;
 
     /**
@@ -127,7 +129,7 @@ public:
     void fadeOut();
     void fakeFadeOut();
 
-    void setGeometry(const QRectF& rect); // reimp
+    void setGeometry(const QRectF& rect) Q_DECL_OVERRIDE;
 
     int sortKey() const;
     void setSortKey(int sortKey);
@@ -145,6 +147,8 @@ public Q_SLOTS:
 
     void setZoomToFit(bool);
 
+    void setZoomToFitWidth(bool);
+
     void setPosition(const QPoint&);
 
     void hideAndDeleteLater();
@@ -175,6 +179,8 @@ Q_SIGNALS:
 
     void zoomToFitChanged(bool);
 
+    void zoomToFitWidthChanged(bool);
+
     void positionChanged();
 
     void hudTrashClicked(DocumentView*);
@@ -189,11 +195,12 @@ Q_SIGNALS:
     void isAnimatedChanged();
 
 protected:
-    void paint(QPainter* painter, const QStyleOptionGraphicsItem* option, QWidget* widget = 0);
+    void paint(QPainter* painter, const QStyleOptionGraphicsItem* option, QWidget* widget = 0) Q_DECL_OVERRIDE;
 
-    void wheelEvent(QGraphicsSceneWheelEvent* event);
-    void contextMenuEvent(QGraphicsSceneContextMenuEvent* event);
-    bool sceneEventFilter(QGraphicsItem*, QEvent*);
+    void resizeEvent(QGraphicsSceneResizeEvent* event) Q_DECL_OVERRIDE;
+    void wheelEvent(QGraphicsSceneWheelEvent* event) Q_DECL_OVERRIDE;
+    void contextMenuEvent(QGraphicsSceneContextMenuEvent* event) Q_DECL_OVERRIDE;
+    bool sceneEventFilter(QGraphicsItem*, QEvent*) Q_DECL_OVERRIDE;
 
 private Q_SLOTS:
     void finishOpenUrl();
@@ -207,7 +214,7 @@ private Q_SLOTS:
 
     void slotZoomChanged(qreal);
 
-    void slotBusyChanged(const KUrl&, bool);
+    void slotBusyChanged(const QUrl&, bool);
 
     void emitHudTrashClicked();
     void emitHudDeselectClicked();
