@@ -19,14 +19,14 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 */
 // Self
-#include "messageviewadapter.moc"
+#include "messageviewadapter.h"
 
 // Qt
 #include <QGraphicsProxyWidget>
+#include <QDebug>
 
 // KDE
-#include <KDebug>
-#include <KLocale>
+#include <KLocalizedString>
 
 // Local
 #include <lib/document/document.h>
