@@ -48,6 +48,7 @@ RasterImageViewAdapter::RasterImageViewAdapter()
     d->mView = new RasterImageView;
     connect(d->mView, &RasterImageView::zoomChanged, this, &RasterImageViewAdapter::zoomChanged);
     connect(d->mView, &RasterImageView::zoomToFitChanged, this, &RasterImageViewAdapter::zoomToFitChanged);
+    connect(d->mView, &RasterImageView::zoomToFitWidthChanged, this, &RasterImageViewAdapter::zoomToFitWidthChanged);
     connect(d->mView, &RasterImageView::zoomInRequested, this, &RasterImageViewAdapter::zoomInRequested);
     connect(d->mView, &RasterImageView::zoomOutRequested, this, &RasterImageViewAdapter::zoomOutRequested);
     connect(d->mView, &RasterImageView::scrollPosChanged, this, &RasterImageViewAdapter::scrollPosChanged);
@@ -93,11 +94,21 @@ void RasterImageViewAdapter::setZoomToFit(bool on)
     d->mView->setZoomToFit(on);
 }
 
+void RasterImageViewAdapter::setZoomToFitWidth(bool on)
+{
+    d->mView->setZoomToFitWidth(on);
+}
+
 bool RasterImageViewAdapter::zoomToFit() const
 {
     return d->mView->zoomToFit();
 }
 
+bool RasterImageViewAdapter::zoomToFitWidth() const
+{
+    return d->mView->zoomToFitWidth();
+}
+
 void RasterImageViewAdapter::setZoom(qreal zoom, const QPointF& center)
 {
     d->mView->setZoom(zoom, center);
@@ -108,6 +119,11 @@ qreal RasterImageViewAdapter::computeZoomToFit() const
     return d->mView->computeZoomToFit();
 }
 
+qreal RasterImageViewAdapter::computeZoomToFitWidth() const
+{
+    return d->mView->computeZoomToFitWidth();
+}
+
 Document::Ptr RasterImageViewAdapter::document() const
 {
     return d->mView->document();
