@@ -20,14 +20,17 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 // Self
 #include "imagemetainfomodel.h"
+#include "config-gwenview.h"
 
 // Qt
+#include <QSize>
+#include <QDebug>
+#include <QLocale>
 
 // KDE
-#include <KDebug>
 #include <KFileItem>
-#include <KGlobal>
-#include <KLocale>
+#include <KLocalizedString>
+#include <KFormat>
 
 // Exiv2
 #include <exiv2/exif.hpp>
@@ -35,6 +38,10 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 #include <exiv2/iptc.hpp>
 
 // Local
+#ifdef HAVE_FITS
+#include "imageformats/fitsformat/fitsdata.h"
+#include "urlutils.h"
+#endif
 
 namespace Gwenview
 {
@@ -44,6 +51,9 @@ enum GroupRow {
     NoGroup = -1,
     GeneralGroup,
     ExifGroup,
+#ifdef HAVE_FITS
+    FitsGroup,
+#endif
     IptcGroup,
     XmpGroup
 };
@@ -76,12 +86,12 @@ public:
             return mValue;
         }
         void setValue(const QString& value)
-    {
+        {
             mValue = value.trimmed();
         }
 
         void appendValue(const QString& value)
-    {
+        {
             if (mValue.length() > 0) {
                 mValue += '\n';
             }
@@ -207,7 +217,7 @@ struct ImageMetaInfoModelPrivate
         MetaInfoGroup* group = mMetaInfoGroupVector[groupRow];
         int entryRow = group->getRowForKey(key);
         if (entryRow == MetaInfoGroup::InvalidRow) {
-            kWarning() << "No row for key" << key;
+            qWarning() << "No row for key" << key;
             return;
         }
         group->setValueForKeyAt(entryRow, value);
@@ -227,7 +237,7 @@ struct ImageMetaInfoModelPrivate
         }
 
         if (index.internalId() == NoGroupSpace) {
-            return QVariant(QString());
+            return QString();
         }
 
         MetaInfoGroup* group = mMetaInfoGroupVector[index.internalId()];
@@ -281,7 +291,7 @@ struct ImageMetaInfoModelPrivate
                     hash.insert(key, new MetaInfoGroup::Entry(key, label, value));
                 }
             } catch (const Exiv2::Error& error) {
-                kWarning() << "Failed to read some meta info:" << error.what();
+                qWarning() << "Failed to read some meta info:" << error.what();
             }
         }
 
@@ -300,9 +310,16 @@ ImageMetaInfoModel::ImageMetaInfoModel()
 : d(new ImageMetaInfoModelPrivate)
 {
     d->q = this;
+#ifdef HAVE_FITS
+    d->mMetaInfoGroupVector.resize(5);
+#else
     d->mMetaInfoGroupVector.resize(4);
+#endif
     d->mMetaInfoGroupVector[GeneralGroup] = new MetaInfoGroup(i18nc("@title:group General info about the image", "General"));
     d->mMetaInfoGroupVector[ExifGroup] = new MetaInfoGroup("EXIF");
+#ifdef HAVE_FITS
+    d->mMetaInfoGroupVector[FitsGroup] = new MetaInfoGroup("FITS");
+#endif
     d->mMetaInfoGroupVector[IptcGroup] = new MetaInfoGroup("IPTC");
     d->mMetaInfoGroupVector[XmpGroup]  = new MetaInfoGroup("XMP");
     d->initGeneralGroup();
@@ -314,14 +331,72 @@ ImageMetaInfoModel::~ImageMetaInfoModel()
     delete d;
 }
 
-void ImageMetaInfoModel::setUrl(const KUrl& url)
+void ImageMetaInfoModel::setUrl(const QUrl &url)
 {
-    KFileItem item(KFileItem::Unknown, KFileItem::Unknown, url);
-    QString sizeString = KGlobal::locale()->formatByteSize(item.size());
+    KFileItem item(url);
+    const QString sizeString = KFormat().formatByteSize(item.size());
+    const QString timeString = QLocale().toString(item.time(KFileItem::ModificationTime), QLocale::LongFormat);
 
     d->setGroupEntryValue(GeneralGroup, "General.Name", item.name());
     d->setGroupEntryValue(GeneralGroup, "General.Size", sizeString);
-    d->setGroupEntryValue(GeneralGroup, "General.Time", item.timeString());
+    d->setGroupEntryValue(GeneralGroup, "General.Time", timeString);
+
+#ifdef HAVE_FITS
+    if (UrlUtils::urlIsFastLocalFile(url) && (url.fileName().endsWith(".fit", Qt::CaseInsensitive) ||
+        url.fileName().endsWith(".fits", Qt::CaseInsensitive))) {
+        FITSData fitsLoader;
+        MetaInfoGroup* group = d->mMetaInfoGroupVector[FitsGroup];
+        QFile file(url.toLocalFile());
+
+        if (!file.open(QIODevice::ReadOnly)) {
+            return;
+        }
+
+        if (fitsLoader.loadFITS(file)) {
+            QString recordList;
+            int nkeys = 0;
+
+            fitsLoader.getFITSRecord(recordList, nkeys);
+            for (int i = 0; i < nkeys; i++)
+            {
+                QString record = recordList.mid(i * 80, 80);
+                QString key;
+                QString keyStr;
+                QString value;
+
+                if (!record.contains("=")) {
+                    key = record.section(' ', 0, 0).simplified();
+                    keyStr = key;
+                    value = record.section(' ', 1, -1).simplified();
+                } else {
+                    key = record.section('=', 0, 0).simplified();
+                    if (record.contains('/')) {
+                        keyStr = record.section('/', -1, -1).simplified();
+                        value = record.section('=', 1, -1).section('/', 0, 0);
+                    } else {
+                        keyStr = key;
+                        value = record.section('=', 1, -1);
+                    }
+                    value.remove("\'");
+                    value = value.simplified();
+                }
+                if (value.isEmpty()) {
+                    continue;
+                }
+
+                // Check if the value is a number and make it more readable
+                bool ok = false;
+                float number = value.toFloat(&ok);
+
+                if (ok) {
+                    value = QString::number(number);
+                }
+
+                group->addEntry("Fits."+key, keyStr, value);
+            }
+        }
+    }
+#endif
 }
 
 void ImageMetaInfoModel::setImageSize(const QSize& size)
@@ -387,12 +462,16 @@ void ImageMetaInfoModel::getInfoForKey(const QString& key, QString* label, QStri
         group = d->mMetaInfoGroupVector[GeneralGroup];
     } else if (key.startsWith(QLatin1String("Exif"))) {
         group = d->mMetaInfoGroupVector[ExifGroup];
+#ifdef HAVE_FITS
+    } else if (key.startsWith(QLatin1String("Fits"))) {
+        group = d->mMetaInfoGroupVector[FitsGroup];
+#endif
     } else if (key.startsWith(QLatin1String("Iptc"))) {
         group = d->mMetaInfoGroupVector[IptcGroup];
     } else if (key.startsWith(QLatin1String("Xmp"))) {
         group = d->mMetaInfoGroupVector[XmpGroup];
     } else {
-        kWarning() << "Unknown metainfo key" << key;
+        qWarning() << "Unknown metainfo key" << key;
         return;
     }
     group->getInfoForKey(key, label, value);
@@ -489,7 +568,7 @@ QVariant ImageMetaInfoModel::headerData(int section, Qt::Orientation orientation
     } else if (section == 1) {
         caption = i18nc("@title:column", "Value");
     } else {
-        kWarning() << "Unknown section" << section;
+        qWarning() << "Unknown section" << section;
     }
 
     return QVariant(caption);
