@@ -41,9 +41,7 @@
 // KDE
 #include <KIO/JobUiDelegate>
 #include <KIO/PreviewJob>
-#include <KStandardDirs>
 #include <KJobWidgets>
-#include <KFileMetaInfo>
 
 // Local
 #include "mimetypeutils.h"
@@ -436,21 +434,21 @@ void ThumbnailProvider::checkThumbnail()
     LOG("Stat thumb" << mThumbnailPath);
 
     QImage thumb = loadThumbnailFromCache();
-    KIO::filesize_t fileSize = thumb.text("Thumb::Size", 0).toULongLong();
+    KIO::filesize_t fileSize = thumb.text("Thumb::Size").toULongLong();
     if (!thumb.isNull()) {
-        if (thumb.text("Thumb::URI", 0) == mOriginalUri &&
-                thumb.text("Thumb::MTime", 0).toInt() == mOriginalTime &&
+        if (thumb.text("Thumb::URI") == mOriginalUri &&
+                thumb.text("Thumb::MTime").toInt() == mOriginalTime &&
                  (fileSize == 0 || fileSize == mOriginalFileSize)) {
             int width = 0, height = 0;
             QSize size;
             bool ok;
 
-            width = thumb.text("Thumb::Image::Width", 0).toInt(&ok);
-            if (ok) height = thumb.text("Thumb::Image::Height", 0).toInt(&ok);
+            width = thumb.text("Thumb::Image::Width").toInt(&ok);
+            if (ok) height = thumb.text("Thumb::Image::Height").toInt(&ok);
             if (ok) {
                 size = QSize(width, height);
             } else {
-                qWarning() << "Thumbnail for" << mOriginalUri << "does not contain correct image size information";
+                LOG("Thumbnail for" << mOriginalUri << "does not contain correct image size information");
                 // Don't try to determine the size of a video, it probably won't work and
                 // will cause high I/O usage with big files (bug #307007).
                 if (MimeTypeUtils::urlKind(mCurrentUrl) == MimeTypeUtils::KIND_VIDEO) {
@@ -458,17 +456,6 @@ void ThumbnailProvider::checkThumbnail()
                     determineNextIcon();
                     return;
                 }
-                KFileMetaInfo fmi(mCurrentUrl);
-                if (fmi.isValid()) {
-                    KFileMetaInfoItem item = fmi.item("Dimensions");
-                    if (item.isValid()) {
-                        size = item.value().toSize();
-                    } else {
-                        qWarning() << "KFileMetaInfoItem for" << mOriginalUri << "did not get image size information";
-                    }
-                } else {
-                    qWarning() << "Could not get a valid KFileMetaInfo instance for" << mOriginalUri;
-                }
             }
             emitThumbnailLoaded(thumb, size);
             determineNextIcon();
