@@ -44,11 +44,11 @@ public:
     ThumbnailBarItemDelegate(ThumbnailView*);
     ~ThumbnailBarItemDelegate();
 
-    virtual void paint(QPainter * painter, const QStyleOptionViewItem & option, const QModelIndex & index) const;
-    virtual QSize sizeHint(const QStyleOptionViewItem & /*option*/, const QModelIndex & /*index*/) const;
+    virtual void paint(QPainter * painter, const QStyleOptionViewItem & option, const QModelIndex & index) const Q_DECL_OVERRIDE;
+    virtual QSize sizeHint(const QStyleOptionViewItem & /*option*/, const QModelIndex & /*index*/) const Q_DECL_OVERRIDE;
 
 protected:
-    virtual bool eventFilter(QObject*, QEvent*);
+    virtual bool eventFilter(QObject*, QEvent*) Q_DECL_OVERRIDE;
 
 private Q_SLOTS:
     void toggleSelection();
@@ -73,9 +73,9 @@ public:
     void setRowCount(int);
 
 protected:
-    virtual void resizeEvent(QResizeEvent * event);
-    virtual void wheelEvent(QWheelEvent* event);
-    virtual void selectionChanged(const QItemSelection& selected, const QItemSelection& deselected);
+    void resizeEvent(QResizeEvent * event) Q_DECL_OVERRIDE;
+    void wheelEvent(QWheelEvent* event) Q_DECL_OVERRIDE;
+    void selectionChanged(const QItemSelection& selected, const QItemSelection& deselected) Q_DECL_OVERRIDE;
 
 private Q_SLOTS:
     void slotFrameChanged(int);
